===================
frappedataset
===================

``frappedataset`` is the FRAPPE campaign dataset for boxmox/beatbox

Documentation
=============

maintained at https://boxmodeling.meteo.physik.uni-muenchen.de/documentation

Installation
============